@@ -154,7 +154,12 @@ class PrepareLines(object):
                 end_pnt = end_points[piece]
             start_distance = round(geom.project(start_pnt), 3)
             end_distance = round(geom.project(end_pnt), 3)
-            coords = list(geom.coords)
+
+            # Don't use the z-coordinate
+            if geom.has_z:
+                coords = [(x, y) for x, y, z in geom.coords]
+            else:
+                coords = list(geom.coords)
             start_set = False
             # no additional calc points
             if start_distance <= 0.0 and end_distance >= geom.length:
@@ -249,6 +254,12 @@ class PrepareChannels(object):
         channels_numpy_array_dict = db_objects_to_numpy_array_dict(
             threedi_datasource.v2_channels, channels_field_names)
 
+        # discharge_coefficient defaults to 1.0 for channels
+        channels_field_names.append('discharge_coefficient')
+        channels_numpy_array_dict['discharge_coefficient'] = np.ones(
+            len(content_pk), dtype=np.float32
+        )
+
         add_or_update_datasets(
             line_group, channels_numpy_array_dict,
             channels_field_names,
@@ -291,6 +302,12 @@ class PreparePipes(object):
         pipes_numpy_array_dict = db_objects_to_numpy_array_dict(
             threedi_datasource.v2_pipes, pipes_field_names)
 
+        # discharge_coefficient defaults to 1.0 for pipes
+        pipes_field_names.append('discharge_coefficient')
+        pipes_numpy_array_dict['discharge_coefficient'] = np.ones(
+            len(content_pk), dtype=np.float32
+        )
+
         add_or_update_datasets(
             line_group, pipes_numpy_array_dict,
             pipes_field_names,
